@@ -22,7 +22,8 @@
 #include "backtraceparsercdb.h"
 #include "backtraceparsernull.h"
 #include "drkonqi_parser_debug.h"
-#include <QRegExp>
+
+#include <QRegularExpression>
 #include <QMetaEnum>
 
 //factory
@@ -145,24 +146,25 @@ static bool lineIsStackBase(const BacktraceLine & line)
         || line.rating() == BacktraceLine::MissingFunction )
         return false;
 
-    //this is the base frame for all threads except the main thread
-    //FIXME that probably works only on linux
-    if ( line.functionName() == QLatin1String("start_thread") )
-        return true;
-
-    QRegExp regExp;
-    regExp.setPattern(QStringLiteral("(kde)?main")); //main() or kdemain() is the base for the main thread
-    if ( regExp.exactMatch(line.functionName()) )
+    // "start_thread" is the base frame for all threads except the main thread, FIXME "start_thread"
+    // probably works only on linux
+    // main() or kdemain() is the base for the main thread
+    if (line.functionName() == QLatin1String("start_thread")
+        || line.functionName() == QLatin1String("main")
+        || line.functionName() == QLatin1String("kdemain")) {
         return true;
+    }
 
     //HACK for better rating. we ignore all stack frames below any function that matches
     //the following regular expression. The functions that match this expression are usually
     //"QApplicationPrivate::notify_helper", "QApplication::notify" and similar, which
     //are used to send any kind of event to the Qt application. All stack frames below this,
     //with or without debug symbols, are useless to KDE developers, so we ignore them.
-    regExp.setPattern(QStringLiteral("(Q|K)(Core)?Application(Private)?::notify.*"));
-    if ( regExp.exactMatch(line.functionName()) )
+    const QRegularExpression re(QRegularExpression::anchoredPattern(
+                                    QStringLiteral("(Q|K)(Core)?Application(Private)?::notify.*")));
+    if (re.match(line.functionName()).hasMatch()) {
         return true;
+    }
 
     //attempt to recognize crashes that happen after main has returned (bug 200993)
     if ( line.functionName() == QLatin1String("~KCleanUpGlobalStatic") ||
@@ -198,20 +200,23 @@ static bool lineIsStackTop(const BacktraceLine & line)
    for some reason. Currently it ignores all libc/libstdc++/libpthread functions. */
 static bool lineShouldBeIgnored(const BacktraceLine & line)
 {
-    if ( line.libraryName().contains(QLatin1String("libc.so"))
-        || line.libraryName().contains(QLatin1String("libstdc++.so"))
-        || line.functionName().startsWith(QLatin1String("*__GI_")) //glibc2.9 uses *__GI_ as prefix
-        || line.libraryName().contains(QLatin1String("libpthread.so"))
-        || line.libraryName().contains(QLatin1String("libglib-2.0.so"))
-#ifdef Q_OS_MACOS
-        || (line.libraryName().startsWith(QLatin1String("libsystem_")) && line.libraryName().endsWith(QLatin1String(".dylib")))
-        || line.libraryName().contains(QLatin1String("Foundation`"))
-#endif
-        || line.libraryName().contains(QLatin1String("ntdll.dll"))
-        || line.libraryName().contains(QLatin1String("kernel32.dll"))
-        || line.functionName().contains(QLatin1String("_tmain"))
-        || line.functionName() == QLatin1String("WinMain") )
+    if (line.libraryName().contains(QLatin1String("libc.so"))
+            || line.libraryName().contains(QLatin1String("libstdc++.so"))
+            || line.functionName().startsWith(QLatin1String("*__GI_")) //glibc2.9 uses *__GI_ as prefix
+            || line.libraryName().contains(QLatin1String("libpthread.so"))
+            || line.libraryName().contains(QLatin1String("libglib-2.0.so"))
+            || line.functionName() == QLatin1String("__libc_start_main") // below main on apps without symbols
+            || line.functionName() == QLatin1String("_start") // below main on apps without symbols
+        #ifdef Q_OS_MACOS
+            || (line.libraryName().startsWith(QLatin1String("libsystem_")) && line.libraryName().endsWith(QLatin1String(".dylib")))
+            || line.libraryName().contains(QLatin1String("Foundation`"))
+        #endif
+            || line.libraryName().contains(QLatin1String("ntdll.dll"))
+            || line.libraryName().contains(QLatin1String("kernel32.dll"))
+            || line.functionName().contains(QLatin1String("_tmain"))
+            || line.functionName() == QLatin1String("WinMain")) {
         return true;
+    }
 
     return false;
 }
@@ -400,4 +405,11 @@ void BacktraceParser::calculateRatingData()
     qCDebug(DRKONQI_PARSER_LOG) << "Have seen stack base:" << haveSeenStackBase << "Lines counted:" << counter;
 }
 
-
+QString BacktraceParser::informationLines() const
+{
+    Q_D(const BacktraceParser);
+    QString ret = d->m_infoLines.join(QLatin1Char('\n'));
+    if (!ret.endsWith(QLatin1Char('\n')))
+        ret += QLatin1Char('\n');
+    return ret;
+}
